@@ -46,7 +46,7 @@ pub fn get_aggregator_result(aggregator: &AggregatorState) -> Result<RoundResult
 
 pub fn fast_feed_result(account_info: &AccountInfo) -> Result<FastRoundResult, ProgramError> {
     let state_buffer = account_info.try_borrow_data()?;
-    let acc_data = fast_from_bytes::<FastRoundResultAccountData>(&state_buffer[1..])?;
+    let acc_data = fast_from_bytes(&state_buffer[1..])?;
     Ok(acc_data.result.clone())
 }
 
